<?php

namespace Drupal\config_actions\Plugin\ConfigActions;

use Drupal\config_actions\ConfigActionsPluginBase;

/**
 * Plugin for including an action from another module.
 *
 * @ConfigActionsPlugin(
 *   id = "include",
 *   description = @Translation("Include action."),
 *   options = {
 *     "module" = "",
 *     "file" = "",
 *     "action" = "",
 *   }
 * )
 */
class ConfigActionsInclude extends ConfigActionsPluginBase {

  /**
   * Name of module containing action.
   * @var string
   */
  protected $module;

  /**
   * Optional Name of file to include.
   * @var string
   */
  protected $file;

  /**
   * Optional Name of action to include.
   * @var string
   */
  protected $action;

  /**
   * Remove plugin-specific options to just leave those to override import.
   * @param $action
   */
  protected function cleanAction(&$action) {
    unset($action['plugin']);
    unset($action['module']);
    unset($action['file']);
    unset($action['action']);
  }

  /**
   * Main execute to perform the include
   */
  public function execute(array $action) {
    $this->cleanAction($action);
    return $this->actionService->importAction($this->module, $this->action, $this->file, $action);
  }

}
